@@ -8,5 +8,8 @@ urlpatterns = patterns('large_data_admin.views',
     url(r'^check/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'check_json'),
     url(r'^selected/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'selected_json'),
 
+    url(r'^many-to-many/list/add/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'many_to_namy_list_add_view'),
+    url(r'^many-to-many/list/rm/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'many_to_namy_list_rm_view'),
+
     url(r'^select/add/(?P<model>[\w\-.]+)/$', 'select_add_json'),
 )
