@@ -2,9 +2,11 @@ from django.db.models import get_model
 from django.http import HttpResponse
 from django.utils import simplejson
 from django.template.defaultfilters import slugify
+from django.shortcuts import render_to_response
+from django.conf import settings
 
 def add_json(request, app, model, pk, field):
-    value = request.GET.get("q")
+    value = request.GET.get("q", "")
     data = []
 
     Model = get_model(app, model)
@@ -20,7 +22,7 @@ def add_json(request, app, model, pk, field):
     return HttpResponse(simplejson.dumps(data))
 
 def rm_json(request, app, model, pk, field):
-    value = request.GET.get("q")
+    value = request.GET.get("q", "")
     data = []
 
     Model = get_model(app, model)
@@ -50,7 +52,7 @@ def rm_process(request, app, model, pk, field, value):
     return HttpResponse("")
 
 def check_json(request, app, model, pk, field):
-    value = request.GET.get("q")
+    value = request.GET.get("q", "")
     data = []
 
     Model = get_model(app, model)
@@ -77,7 +79,7 @@ def selected_json(request, app, model, pk, field):
 
 
 def select_add_json(request, model):
-    value = request.GET.get("q")
+    value = request.GET.get("q", "")
     data = []
 
     import importlib
@@ -92,4 +94,49 @@ def select_add_json(request, model):
         if slugify(value) in slugify(obj.__unicode__()):
             data.append((obj.pk, obj.__unicode__()))
 
-    return HttpResponse(simplejson.dumps(data))
\ No newline at end of file
+    return HttpResponse(simplejson.dumps(data))
+
+def many_to_namy_list_add_view(request, app, model, pk, field):
+    value = request.GET.get("q", "")
+    data = []
+
+    Model = get_model(app, model)
+    instance = Model.objects.get(pk=pk)
+    KeyModel = getattr(instance, field).model
+
+    objs = KeyModel.objects.all()
+    selected = getattr(instance, field).all()
+    for obj in objs:
+        if slugify(value) in slugify(obj.__unicode__()) and not obj in selected:
+            data.append((obj.pk, obj.__unicode__()))
+
+    return render_to_response("large_data_admin/widget_list_add.html",
+        {
+            "data": data,
+            "STATIC_URL": settings.STATIC_URL,
+            "app": app,
+            "model": model,
+            "field": field,
+        },)
+
+
+def many_to_namy_list_rm_view(request, app, model, pk, field):
+    value = request.GET.get("q", "")
+    data = []
+
+    Model = get_model(app, model)
+    instance = Model.objects.get(pk=pk)
+    KeyModel = getattr(instance, field).model
+
+    for obj in getattr(instance, field).all():
+        if slugify(value) in slugify(obj.__unicode__()):
+            data.append((obj.pk, obj.__unicode__()))
+
+    return render_to_response("large_data_admin/widget_list_rm.html",
+        {
+            "data": data,
+            "STATIC_URL": settings.STATIC_URL,
+            "app": app,
+            "model": model,
+            "field": field,
+        },)
\ No newline at end of file
